@@ -1,6 +1,5 @@
 # coding=utf-8
 import datetime
-import time
 
 from simplyblock_core.models.base_model import BaseModel
 
@@ -18,6 +17,10 @@ class JobSchedule(BaseModel):
     FN_FAILED_DEV_MIG = "failed_device_migration"
     FN_NEW_DEV_MIG = "new_device_migration"
     FN_NODE_ADD = "node_add"
+    FN_PORT_ALLOW = "port_allow"
+    FN_BALANCING_AFTER_NODE_RESTART = "balancing_on_restart"
+    FN_BALANCING_AFTER_DEV_REMOVE = "balancing_on_dev_rem"
+    FN_BALANCING_AFTER_DEV_EXPANSION = "balancing_on_dev_add"
 
     canceled: bool = False
     cluster_id: str = ""
@@ -29,9 +32,10 @@ class JobSchedule(BaseModel):
     max_retry: int = -1
     node_id: str = ""
     retry: int = 0
+    sub_tasks: list = []
 
     def write_to_db(self, kv_store=None):
-        self.updated_at = str(datetime.datetime.now())
+        self.updated_at = str(datetime.datetime.now(datetime.timezone.utc))
         super().write_to_db(kv_store)
 
 
