@@ -1,7 +1,5 @@
 # coding=utf-8
 
-from datetime import datetime
-
 from simplyblock_core.models.base_model import BaseNodeObject
 
 
@@ -12,3 +10,4 @@ class MgmtNode(BaseNodeObject):
     docker_ip_port: str = ""
     hostname: str = ""
     mgmt_ip: str = ""
+    mode: str = ""
