@@ -10,9 +10,14 @@ logger = logging.getLogger()
 
 
 def __run_script(args: list):
-    output = subprocess.check_output(args, text=True, stderr=subprocess.STDOUT)
-    if output:
-        logger.debug(output.strip())
+    try:
+        output = subprocess.check_output(args, timeout=720, text=True, stderr=subprocess.STDOUT)
+        if output:
+            logger.debug(output.strip())
+    except subprocess.CalledProcessError as e:
+        logger.debug(f"Command failed with return code: {e.returncode}")
+        logger.debug((f"Captured output:\n {e.output}"))
+        raise
 
 
 def install_deps(mode):
